@@ -1,16 +1,17 @@
 """django-cms plugin for the ``document_library`` app."""
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
-from cms.models.pluginmodel import CMSPlugin
 from django.utils.translation import ugettext_lazy as _
 
 from simple_translation.middleware import filter_queryset_language
 
 from document_library.models import Document, DocumentCategory
 
+from .models import DocumentPlugin
+
 
 class DocumentLibraryPlugin(CMSPluginBase):
-    model = CMSPlugin
+    model = DocumentPlugin
     name = _('Document Library Plugin')
     render_template = "document_library/document_library_plugin.html"
 
@@ -18,6 +19,7 @@ class DocumentLibraryPlugin(CMSPluginBase):
         qs = Document.objects.published(context.get('request')).all()
         qs = filter_queryset_language(context.get('request'), qs)
         context.update({
+            'document': instance.document,
             'documents': qs,
             'categories': DocumentCategory.objects.all(),
         })
