@@ -7,6 +7,7 @@ from django.db import models
 from django.utils.translation import get_language
 from django.utils.translation import ugettext_lazy as _
 
+from cms.models.pluginmodel import CMSPlugin
 from django_libs.models_mixins import SimpleTranslationMixin
 from djangocms_utils.fields import M2MPlaceholderField
 from filer.fields.file import FilerFileField
@@ -108,6 +109,14 @@ class DocumentManager(models.Manager):
         return qs
 
 
+class DocumentPlugin(CMSPlugin):
+    """Class to extend the `CMSPlugin` pluginmodel."""
+    document = models.ForeignKey(
+        'document_library.Document',
+        verbose_name=_('Document plugin'),
+    )
+
+
 class Document(SimpleTranslationMixin, models.Model):
     """
     A document consists of a title and description and a number of filer-files.
